@@ -105,7 +105,7 @@ def _buildrpms(deps, channel, options):
 
 
 def _build_rpm(channel, options):
-    if has_changes() and channel != 'dev':
+    if has_changes() and channel != 'dev' and not options.force:
         print('the code was changed, aborting!')
         sys.exit(0)
 
